@@ -18,10 +18,29 @@ Kinds of moose and other antlered, er, moose.
 
 Gaal Yahas.
 
-Introduced in Acme-MetaSyntactic version 0.46, published on October 31, 2005.
+=head1 CHANGES
 
-Received its own version number for Acme-MetaSyntactic-Themes version 1.000,
-published on May 7, 2012.
+=over 4
+
+=item *
+
+2012-05-07 - v1.000
+
+Received its own version number in Acme-MetaSyntactic-Themes version 1.000.
+
+=item *
+
+2005-10-31
+
+Introduced in Acme-MetaSyntactic version 0.46.
+
+=item *
+
+2005-09-16
+
+Submitted by Gaal Yahas.
+
+=back
 
 =head1 SEE ALSO
 
