@@ -2,7 +2,7 @@ package Acme::MetaSyntactic::simpsons;
 use strict;
 use Acme::MetaSyntactic::List;
 our @ISA = qw( Acme::MetaSyntactic::List );
-our $VERSION = '1.001';
+our $VERSION = '1.002';
 __PACKAGE__->init();
 
 our %Remote = (
@@ -11,6 +11,7 @@ our %Remote = (
         my $i = 1;
         return
           grep !/^(?:The_Simpsons|Simpson_family)$/, map {
+            s/%26/and/g;
             s/%27//g;
             s/%C3%9C/U/g;
             s/%C3%A9/e/g;
@@ -46,6 +47,12 @@ Philippe "BooK" Bruhat.
 
 =item *
 
+2021-04-30 - v1.002
+
+Updated from the source web site in Acme-MetaSyntactic-Themes version 1.055.
+
+=item *
+
 2019-07-29 - v1.001
 
 New data source: L<https://simpsons.fandom.com/wiki/Portal:All_Simpson_Characters>.
@@ -100,9 +107,13 @@ Adrian_Belew
 Agnes_Flanders
 Agnes_Skinner
 Akira
+Alaska_Nebraska
+Alcatraaz
 Alex_Whitney
 Alice_Glick
+Alien_2
 Alien_couch_gag
+Ali_Rudy_Vallee
 Allison_Taylor
 Alvarine_Bisque
 Amber_Simpson
@@ -111,13 +122,13 @@ Amish_Man
 Anastasia
 Andy_Hamilton
 Angelica
+Angelica_Button
 Annie_Ant
 Annie_Dubinsky
 Annika_Van_Houten
 Anoop_Nahasapeemapetilon
 Apu_Nahasapeemapetilon
 Apu_Nahasapeemapetilon_Sr
-Apus_Mother
 Aristotle_Amadopolis
 Arnie_Pye
 Arnold_Schwarzenegger
@@ -126,10 +137,7 @@ Arthur_Student
 Artie_Ziff
 Art_teacher
 Ashley
-Audrey_McConnells_Student_1
-Audrey_McConnells_Student_2
-Audrey_McConnells_Student_8
-Audrey_McConnells_Student_Four
+Audrey_McConnell
 Augusta_Flanders
 Babysitting_Lady
 Ballet_Teacher
@@ -140,16 +148,20 @@ Barrow_Spuckler
 Bart_Simpson
 Bart_Simpson_Jr
 Bashir_bin_Laden
+Baz
+Bear_Robot
 Beggar_Relative
 Benjamin_nerd
 Benzine_girl
 Bernice_Hibbert
+Bestimus_Muchos
 Bill_KBBL_DJ
 Billy_actor
 Birch_Barlow
 Birthday_Spuckler
 Bitey
 Black_hole_aliens
+Black_Teacher
 Black_Weasel
 Bleeding_Gums_Murphy
 Blinky
@@ -159,31 +171,33 @@ Bodhi
 Bolivian_Tree_Lizard
 Bomb_Disarming_Robot
 Bonnie_Flanders
-Booberella
 Boy_with_bangs
 Boy_with_freckles
 Boy_with_glasses
 Boy_with_shades
 Brandine_Spuckler
+Brenda
 Brittany_Brockman
 Brittany_Spuckler
 Brothers_and_sisters_of_Chin_Ho_and_Chan_Ho
 Brown_haired_girl
 Brunella_Pommelhorst
+Buck_McCoy
+Buck_Mitchell
 Buck_toothed_boy
 Buck_toothed_girl
-Bumblebee_Man
-Burns_Dog
-Burns_Elephant
-Burns_Flying_Monkeys
 Butterfly
+Buzzkill
+Calliope_Juniper
 Canadian_Flanders
 Canary_M_Burns
+Cannibal
 Capital_City_Goofball
 Captain_Jack
 Captain_Lance_Murdock
 Caribbean_Boy
 Carl_Carlson
+Carnage_Destructicus
 Cassidy_Spuckler
 Cecil_Terwilliger
 Celeste
@@ -199,12 +213,15 @@ Chez_Paree_Lobsters
 Chicagoan_man
 Chin_Ho
 Chocolate_rabbits
+Chop_Screwy
 Christmas_Tree_Farm_Hounds
 Chuck_Berger
 Chuck_Muntz
+CHUM
 Clancy_Bouvier
 Clancy_Wiggum
 Claretta_Simpson
+Cleatus_the_Football_Robot
 Cleo_Bouvier
 Cletus_Spuckler
 Clifford_Burns
@@ -220,61 +237,68 @@ Congressman_3
 Connie_Flanders
 Cookie_Kwan
 Cora
+Corey_Masterson
 Cornelia_Hernandez
 Cornelius_Burns
 Corporal_Punishment
 Cosine_Tangent
 Coward
 Cowboy_Bob
+Cregg_Demon
+Cremo_Bot
 Crystal_Meth_Spuckler
 Curious_Bear_Cub
 Cute_Lamb
 Cyrus_Simpson
 Dame_Judith_Terwilliger
 Daphne_Burns
+Dark_Stanley
 Darryl
 Dash_Dingo
 Database
 Dave_Shutton
 Declan_Desmond
+Defunct_Robots
+Delbert
 Dermott_Spuckler
 Dewey_Largo
 Dia_Betty
+Dickie
+Dick_Testiclees
 Didi_Bouvier
 Diggs
 Disco_Stu
-Dog_O_War
 Dog_SNPP
 Dog_The_Lastest_Gun_in_the_West
 Dog_with_Ham
 Dolph_Starbeam
 Don_Brodka
 Donna
-Donnas_friend
 Donny_The_Debarted
 Don_Vittorio_DiMaggio
 Doreena_Burns
 Doris_Freedman
 Doug_nerd
 Drederick_Tatum
+Dr_Egoyan
 Dr_Hector_von_Colossus
-Dr_Hibberts_Second_Daughter
-Dr_Hibberts_Second_Son
+Dr_Hillbilly
 Dr_Simpson
 Dr_Velimirovic
 Dubya_Spuckler
+Duff_Cowboy
 Duffman
 Duff_McShark
 Dulcine_Simpson
 Duncan
 Dwight_Diddlehopper
-Dwight_Diddlehoppers_Accomplice
 Dylan_Spuckler
 Eartha_Kitt_character
 Eckhardt_Simpson
 Eddie
 Eddie_Muntz
 Edna_Krabappel
+El_Divo
 Eleanor_Abernathy
 Elizabeth_Hoover
 Eliza_Simpson
@@ -288,19 +312,21 @@ Erin
 Ernst
 Esquilax
 Estonian_Dwarf
+Eunice_Bouvier
 Evelyn_Graycomb
+Evelyn_Trunch
 Evil_Homer
 Faceless_Man
 Fallout_Boy
-Fat_Tony
 FBI_Agent_2_Homerland
 Female_Mail_Carrier
 Female_Twin
+Femme_Fatale
 Feral_Things
+Fernando_Vidal
 Fido
-Fifth_grade_girl
-Flanders_pet_woodpecker
 Floradora_Flannery
+Floyd
 Fluffy
 Fontanelle_Spuckler
 Four_H_leader
@@ -314,6 +340,7 @@ Freddy
 Freddy_Quimby
 Fred_Kanneke
 Freedom
+French_Chef
 Frog_Prince
 Furious_George
 Gabbo
@@ -326,6 +353,7 @@ Gavin
 Gay_Colonel
 Geech
 General_Sherman
+Gentle_Ben
 George_Burns_character
 Gerald_Samson
 German_Santa_Girl
@@ -340,12 +368,9 @@ Gitmo_Spuckler
 Giuseppe
 Gladys_Gurney
 Gloria_Jailbird
-Glorias_Daughter
-Glorias_Husband
-Glorias_Older_Son
-Glorias_Younger_Son
 Gloria_White_Christmas_Blues
 God
+Goosius
 Gorilla_the_Conqueror
 Grady
 Grandma_Flanders
@@ -355,11 +380,12 @@ Great_Son
 Greta_Wolfcastle
 Gretchen
 Greyhound_Puppies
-Groundskeeper_Willie
+Grief_Counselor
 Guard_Dog
 Gummy_Sue_Spuckler
 Gunter
 Gus_Huebner
+Gym_Teacher
 Ham
 Hamster_Number_1
 Hamster_Number_2
@@ -367,6 +393,7 @@ Handsome_Pete
 Hank_Scorpio
 Hans_Moleman
 Harper_Jambowski
+Headmaster_Greystash
 Heather_Spuckler
 Helen_Lovejoy
 Henry_the_Canary
@@ -387,6 +414,7 @@ Howland_Simpson
 Hubert_Simpson
 Hugo_Simpson_I
 Hugo_Simpson_II
+Humanologist
 Humphrey_Little_Goat
 Hungry_Spuckler_Baby
 Hurt_Leg_Simpson_Relative
@@ -396,10 +424,12 @@ Iggy_Wiggum
 Incest_Spuckler
 Indian_Nerd
 International_Harvester_Spuckler
+Investo
 Ironfist_Burns
-Isabel_Gutierrez
 Itchy
+Itchy_and_Scratchy_robots
 Ivy_Simpson
+Jack_Crowley
 Jack_Deforest
 Jack_Lassen
 Jack_Marley
@@ -410,16 +440,16 @@ Jake_the_Barber
 Jamie
 Jane_Nervous_Goat
 Janey_Powell
-Jasper_Beardly
+Jay_G
 Jay_Sherman
 Jebediah_Springfield
 Jehoshaphat_Flanders
-Jenda_Simpson
 Jenny
 Jeremy_Freedman
 Jeremy_Jailbird
 Jericho
 Jessica_Lovejoy
+Jiff_Simpson
 Jimbo_Jones
 Jitney_Spuckler
 J_Loren_Pryor
@@ -427,13 +457,11 @@ Joe_Puffing_Goat
 Joe_Quimby
 Joey_Crusher
 Joey_mafia
-John_Homers_Phobia
 Johnny_Tightlips
 JoJo_Bouvier
 Jonathan_Frink
 Jordan_Spuckler
 Jose_Flanders
-Jub_Jub
 Judge_Constance_Harm
 Judge_Muntz
 Jug_Band_Manager
@@ -441,6 +469,7 @@ Juliet_Hobbes
 Julio
 Julius_Hibbert
 Just_Stamp_the_Ticket_Man
+Kamala
 Kang
 Kavi_Nahasapeemapetilon
 Kearney_Zzyzwicz
@@ -448,41 +477,38 @@ Kearney_Zzyzwicz_Jr
 Kent_Brockman
 Kevin_Stealing_First_Base
 Khlav_Kalash_vendor
-Kirk_Simpson
+Killhammad_Aieee
+King_Snorky
 Kirk_Van_Houten
+Kissing_Fish
 Kodos
-Krustys_son
 Krusty_the_Clown
 Kumiko_Albertson
 Kwik_E_Mart_President
 Kyle_3rd_Grader
 Kyle_LaBianco
-Kyles_Father
-Kyles_Mother
-Kyles_Sister
+Laddie
 Lady_Nedderly_Flanders
 Lady_Nedebel_Flanders
 Lady_Nedwina_Dredful
 Lambert_Simpson
+Laney_Fontaine
 Langdon_Alger
 Lard_Lad
 Larry_barfly
 Larry_Burns
 Legs
+Lem
 Lenny_Leonard
 Leon_Kompowsky
 Leopold
 Leprechaun
 Lewis_Clark
-Lewis_lookalike
 Lily_Bancroft
 Lindsey_Naegle
 Ling_Bouvier
+Linguo
 Lionel_Hutz
-Lisa_and_Nelsons_children
-Lisas_Friend_2
-Lisas_Friend_3
-Lisas_Friend_Four
 Lisa_Simpson
 Little_Bearded_Woman
 Little_Moe_Szyslak
@@ -509,15 +535,12 @@ Lyla
 Lyle_Lanley
 Mabel_Simpson
 MacArthur_Parker
-Maggies_Husband
 Maggie_Simpson
 Maggie_Simpson_Jr
 Male_Twin
+Malicious_Krubb
 Manjula_Nahasapeemapetilon
-Manjulas_Father
-Manjulas_Mother
 Marcel_Bouvier
-Marges_demons
 Marge_Simpson
 Martha_Prince
 Martha_Quimby
@@ -530,27 +553,28 @@ Mary_Frowning_Cloud
 Mary_Spuckler
 Master_Sushi_Chef
 Mathemagician
-Matt_Groening_character
 Maude_Flanders
 Maude_Flanders_ghost
+Maurice
 Maw_Spuckler
 Maxine_Lombard
 Max_Spuckler
-Mayor_Quimbys_Body_Guards
+Meathook
+Medbot
 Medicine_Woman
 Megan
+Melanie_Upfoot
+Melody
 Melody_Juniper
 Melvin_Van_Horne
-Melvin_Van_Hornes_grandchildren
-Melvin_Van_Hornes_son
 Melvis_Spuckler
+Meredith_Milgram
 Merl
 Mervin_Monroe
+Meteor_Alien
+Meth_Guy
 Mia_Farrow
-Michael_DAmico
-Mikes_Student_1
-Mikes_Student_2
-Mikes_Student_3
+Mike_Benzie
 Milford_Van_Houten
 Milhouse_Van_Houten
 Millionaire_Actor
@@ -561,22 +585,35 @@ Minimum_Wade_Spuckler
 Miss_Springfield
 Moe_Szyslak
 Mojo_the_Helper_Monkey
+Molloy
 Mona_Simpson
 Moshe_Bernstein
-Mr_Burns_older_siblings
+Mr_Becker
 Mr_Costington
+Mr_Glascock
+Mr_Johansen
+Mr_Johnson
+Mr_Kupferberg
 Mr_McGreg
+Mr_Mitchell
 Mrs_Muntz
 Mrs_Vanderbilt
 Mr_Teeny
 Mr_Vanderbilt
 Mr_Winfield
 Ms_Albright
+Ms_Barr
+Ms_Cantwell
+Ms_Myles
+Ms_Phipps
 Mugger
 Multi_eyed_squirrel
-My_Ding_a_Ling_Kid
+Murderpuss
+Mutant_Peacock
+Myra
 Nabendu_Nahasapeemapetilon
 Nana_Sophie_Mussolini
+NASA_Chimp
 Ned_Flanders
 Nedgar_Flanders
 Nediana_Flanders
@@ -588,6 +625,7 @@ Nedwynn_Flanders
 Neil_Terwilliger
 Nelson_Muntz
 Nelson_Muntz_Jr
+Nibbles
 Nick_Riviera
 Nikki_McKenna
 Nina_Skalka
@@ -595,6 +633,7 @@ Noah_Father_Knows_Worst
 Norbert_Van_Houten
 Normal_Head_Joe_Spuckler
 Norman_Van_Horne
+Number_51
 Number_One
 Old_Jewish_Man
 Opal
@@ -602,7 +641,10 @@ Orville_Simpson
 Otto_Graycomb
 Otto_Mann
 Oxycontin_Spuckler
+Ozmodiar
 Pahusacheta_Nahasapeemapetilon
+Parkfield_Servant_1
+Parkfield_Servant_2
 Patches
 Patty_Bouvier
 Pediculus_Spuckler
@@ -611,8 +653,8 @@ Pepita_Hernandez
 Pete_Spuckler
 Phillips
 Photo_Girl
-Picard_Simpson
 Pigeon_Rat
+Ping_Ping
 Pippa_Simpson
 Playground_ghost
 Plopper
@@ -628,20 +670,22 @@ Portuguese_Boy
 Pria_Nahasapeemapetilon
 Princess_Kashmir
 Princess_Penelope
-Prison_Snitch_Simpson_Relative
+Probe_Alien
 Professor_Lombardo
 Professor_Werner_von_Brawn
 Prudence_Simpson
 Prune_Juice_Nerd
 Pyro
 Q_Bert_Spuckler
-Rabbi_Hyman_Krustofsky
+Queenie
+Quinn_Hopper
 Rachel_Jordan
 Rachel_Krustofsky
-Radioactive_Man_character
 Rainier_Wolfcastle
 Ralph_Moaning_Lisa
+Ralph_O_Cop
 Ralph_Wiggum
+Ramrod
 Rangemaster
 Raphael
 Rasputin_the_Friendly_Russian
@@ -651,12 +695,21 @@ Rest_Stop_Spuckler
 Rex_Banner
 Rex_I_Love_Lisa
 Richard
+Rigel_7_Taxi_Driver
+Rigellian_Queen
+Rigellian_Resistance_Leader
+Rigellian_Security_Guard
 Robber_Homer_and_Apu
+Robby_the_Automaton
 Robert_Terwilliger
+Robopet
+Robot_Librarian
+Robot_Workers
 Rod_Flanders
-Roger_Meyers_Jr
+Roger_Meyers_Sr
 Rosa_Barks
 Ross
+Rover_Hendrix
 Roy
 Roy_Snyder
 Rubella_Scabies_Spuckler
@@ -670,8 +723,8 @@ Sam_barfly
 Sandeep_Nahasapeemapetilon
 Sandwich_Delivery_Guy
 Sanjay_Nahasapeemapetilon
-Santas_Little_Helper
 Sarah_Wiggum
+Sara_Sloane
 Sara_Student
 Sashi_Nahasapeemapetilon
 Saul_Bernstein
@@ -682,76 +735,98 @@ Screamapillar
 Sebastian_Cobb
 Selma_Bouvier
 Serak_the_Preparer
+Sex_Toy
 Sexy_Assistant
 Seymour_Skinner
 Seymour_Skinner_real
 Shary_Bobbins
 Shauna_Chalmers
+She_Biscuit
 Shelby
 Sheldon_Skinner
-Sherri_and_Terris_children
 Sherri_Mackleberry
+Sideshow_Raheem
 Singaporean_Girl
 Singing_Girl
 Sir_Nederick_Flanders
-Smilin_Joe_Fission
+Sir_Oinks_A_Lot
+Skippy_Simpson
+Smiley
 Smug_Girl
 Snake_Jailbird
+Snooze
+Snowball_I
 Snowball_II
 Snowball_V
 Sophie_Jensen
 Sophie_Krustofsky
+Space_Marshmallow
 Spirit_Guide
 Springfield_bears
 Springfield_Nuclear_Power_Plant_employee
 Springfield_Pet_Shop_owner
+Squawky
 Stabbed_in_Jail_Spuckler
 Stampy
 Stanley_Simpson
 State_Comptroller_Atkins
+Stewart_Duck
+Sticky_Fingers_Stella
 Stingy
 Strangles
+Sven_Golly
 Sven_Simpson
 Sylvia_Winfield
+Tabitha_Vixx
 Taffy
+Talking_Dog
 Tanya
 Taquito
 Tattoo_Annie
 Taylor_Spuckler
 Ted_Flanders
 Terri_Mackleberry
+The_Great_Raymondo
 The_Human_Fly
+The_Iron_Yuppie
 The_Leader
-The_Nahasapeemapetilon_Octuplets
-The_Nahasapeemapetilon_Octuplets_Octuplets
 The_Rich_Texan
 The_Warden
 The_Yes_Guy
 Three_Unnamed_Spuckler_Babies
+Three_Way
 Tiffany_Spuckler
-Timothy_Lovejoy_Jr
 Tina_Ballerina
 Titania
 Todd_Flanders
 Tommy
+Toot_Toot
 Toshiro
 Tripod_Spuckler
 Trixie_Simpson
 Troy_McClure
+Truckasaurus
 Tumi
+Two_Headed_Dog
 Two_nicorn
-Tyler_Moms_Id_Like_to_Forget
 Tyrone_Simpson
 Ugolin
+Ultrahouse_3000
 Uma_Nahasapeemapetilon
 Unborn_Spuckler_Baby
+Unicorn_Wizard
+Unnamed_blonde_haired_girl
+Unnamed_girl_with_red_glasses
 Unnamed_Latino_Man
 Unnamed_smoking_man
 Unnamed_Spuckler_Baby
 Uter_Zorker
 Veterinarian
+Vicious_Monkeys
+Vicki_Valentine
 Victor_Bouvier
 Victor_Bouvier_II
+Viktor
 Virgil_Simpson
 Wainwright_Montgomery_Burns
 Wanda
@@ -774,11 +849,14 @@ Winifred_Running_Goat
 Winifred_Trout
 Woody_Allen
 Worm_eating_boy
+Xylem
 Yellow_Weasel
 Yuma_Hickman
 Yves_Bouvier
+Zachary_Vaughn
 Zeke_Simpson
 Zeph_Burns
 Zia_Simpson
+Zip_Boys
 Zoe_Spuckler
 Zorina_Ovadia
